@@ -1,21 +1,25 @@
-"""PRAW exception classes.
+"""Async PRAW exception classes.
 
 Includes two main exceptions: :class:`.RedditAPIException` for when something
 goes wrong on the server side, and :class:`.ClientException` when something
 goes wrong on the client side. Both of these classes extend
-:class:`.PRAWException`.
+:class:`.AsyncPRAWException`.
 
 All other exceptions are subclassed from :class:`.ClientException`.
 
 """
+import sys
 from typing import List, Optional, Union
 from warnings import warn
 
 
-class PRAWException(Exception):
+class AsyncPRAWException(Exception):
     """The base Async PRAW Exception that all other exception classes extend."""
 
 
+PRAWException = AsyncPRAWException
+
+
 class RedditErrorItem:
     """Represents a single error returned from Reddit's API."""
 
@@ -28,7 +32,7 @@ class RedditErrorItem:
         return error_str
 
     def __init__(self, error_type: str, message: str, field: Optional[str] = None):
-        """Instantiate an error item.
+        """Initialize an error item.
 
         :param error_type: The error type set on Reddit's end.
         :param message: The associated message for the error.
@@ -50,17 +54,21 @@ class RedditErrorItem:
 
     def __repr__(self):
         """Return repr(self)."""
-        return f"{self.__class__.__name__}(error_type={self.error_type!r}, message={self.message!r}, field={self.field!r})"
+        return (
+            f"{self.__class__.__name__}(error_type={self.error_type!r},"
+            f" message={self.message!r}, field={self.field!r})"
+        )
 
     def __str__(self):
         """Get the message returned from str(self)."""
         return self.error_message
 
 
-class APIException(PRAWException):
+class APIException(AsyncPRAWException):
     """Old class preserved for alias purposes.
 
     .. deprecated:: 7.0
+
         Class :class:`.APIException` has been deprecated in favor of
         :class:`.RedditAPIException`. This class will be removed in Async PRAW 8.0.
     """
@@ -72,7 +80,9 @@ class APIException(PRAWException):
             exception
             if isinstance(exception, RedditErrorItem)
             else RedditErrorItem(
-                exception[0], exception[1], exception[2] if bool(exception[2]) else "",
+                exception[0],
+                exception[1],
+                exception[2] if bool(exception[2]) else "",
             )
             for exception in exceptions
         ]
@@ -101,7 +111,7 @@ class APIException(PRAWException):
             Accessing attributes through instances of
             :class:`.RedditAPIException` is deprecated. This behavior will be
             removed in Async PRAW 8.0. Check out the
-            :ref:`PRAW 7 Migration tutorial <Exception_Handling>` on how to
+            :ref:`Async PRAW 7 Migration tutorial <Exception_Handling>` on how to
             migrate code from this behavior.
 
         """
@@ -124,10 +134,10 @@ class APIException(PRAWException):
 
     def _get_old_attr(self, attrname):
         warn(
-            f"Accessing attribute ``{attrname}`` through APIException is deprecated. "
-            f"This behavior will be removed in Async PRAW 8.0. Check out "
-            f"https://praw.readthedocs.io/en/latest/package_info/praw7_migration.html "
-            f"to learn how to migrate your code.",
+            f"Accessing attribute ``{attrname}`` through APIException is deprecated."
+            " This behavior will be removed in Async PRAW 8.0. Check out"
+            " https://praw.readthedocs.io/en/latest/package_info/praw7_migration.html"
+            " to learn how to migrate your code.",
             category=DeprecationWarning,
             stacklevel=3,
         )
@@ -157,7 +167,7 @@ class RedditAPIException(APIException):
     """Container for error messages from Reddit's API."""
 
 
-class ClientException(PRAWException):
+class ClientException(AsyncPRAWException):
     """Indicate exceptions that don't involve interaction with Reddit's API."""
 
 
@@ -178,8 +188,8 @@ class InvalidFlairTemplateID(ClientException):
     def __init__(self, template_id: str):
         """Initialize the class."""
         super().__init__(
-            f"The flair template id ``{template_id}`` is invalid. If you are trying "
-            f"to create a flair, please use the ``add`` method."
+            f"The flair template id ``{template_id}`` is invalid. If you are trying to"
+            " create a flair, please use the ``add`` method."
         )
 
 
@@ -187,7 +197,7 @@ class InvalidImplicitAuth(ClientException):
     """Indicate exceptions where an implicit auth type is used incorrectly."""
 
     def __init__(self):
-        """Instantize the class."""
+        """Initialize the class."""
         super().__init__("Implicit authorization can only be used with installed apps.")
 
 
@@ -220,8 +230,8 @@ class TooLargeMediaException(ClientException):
         self.maximum_size = maximum_size
         self.actual = actual
         super().__init__(
-            f"The media that you uploaded was too large (maximum size is "
-            f"{maximum_size} bytes, uploaded {actual} bytes)"
+            f"The media that you uploaded was too large (maximum size is {maximum_size}"
+            f" bytes, uploaded {actual} bytes)"
         )
 
 
@@ -232,9 +242,9 @@ class WebSocketException(ClientException):
     def original_exception(self) -> Exception:
         """Access the original_exception attribute (now deprecated)."""
         warn(
-            "Accessing the attribute original_exception is deprecated. Please"
-            " rewrite your code in such a way that this attribute does not"
-            " need to be used. It will be removed in Async PRAW 8.0.",
+            "Accessing the attribute original_exception is deprecated. Please rewrite"
+            " your code in such a way that this attribute does not need to be used. It"
+            " will be removed in Async PRAW 8.0.",
             category=DeprecationWarning,
             stacklevel=2,
         )
@@ -265,10 +275,34 @@ class MediaPostFailed(WebSocketException):
     """Indicate exceptions where media uploads failed.."""
 
     def __init__(self):
-        """Instantiate MediaPostFailed."""
+        """Initialize MediaPostFailed."""
         super().__init__(
-            "The attempted media upload action has failed. Possible causes"
-            " include the corruption of media files. Check that the media "
-            "file can be opened on your local machine.",
+            "The attempted media upload action has failed. Possible causes include the"
+            " corruption of media files. Check that the media file can be opened on"
+            " your local machine.",
             None,
         )
+
+
+# Adapted from https://stackoverflow.com/a/40546615
+class ExceptionWrapper(object):
+    """Wrapper to facilitate showing depreciation for PRAWException class rename."""
+
+    def __init__(self, wrapped):
+        """Initialize Wrapper instance."""
+        self.wrapped = wrapped
+
+    def __getattr__(self, attribute):
+        """Return the value of `attribute`."""
+        if attribute == "PRAWException":
+            warn(
+                "PRAWException as been renamed to AsyncPRAWException. PRAWException "
+                " will be removed in the next version Async PRAW.",
+                category=DeprecationWarning,
+                stacklevel=3,
+            )
+        return getattr(self.wrapped, attribute)
+
+
+if "sphinx" not in sys.modules:
+    sys.modules[__name__] = ExceptionWrapper(sys.modules[__name__])
