@@ -1,4 +1,5 @@
 """Provide the RedditBase class."""
+from copy import deepcopy
 from typing import TYPE_CHECKING, Any, Dict, Optional, Union
 from urllib.parse import urlparse
 
@@ -12,6 +13,13 @@ if TYPE_CHECKING:  # pragma: no cover
 class RedditBase(AsyncPRAWBase):
     """Base class that represents actual Reddit objects."""
 
+    def __deepcopy__(self, memodict={}):
+        """Skip copying ``_reddit`` attribute when preforming a deep copy."""
+        return type(self)(
+            self._reddit,
+            _data=deepcopy({k: v for k, v in self.__dict__.items() if k != "_reddit"}),
+        )
+
     @staticmethod
     def _url_parts(url):
         parsed = urlparse(url)
@@ -32,8 +40,8 @@ class RedditBase(AsyncPRAWBase):
         """Return the value of `attribute`."""
         if not attribute.startswith("_") and not self._fetched:
             raise AttributeError(
-                "{0!r} object has no attribute {1!r}. {0!r} object has not been fetched, "
-                "did you forget to execute '.load()'?".format(
+                "{0!r} object has no attribute {1!r}. {0!r} object has not been"
+                " fetched, did you forget to execute '.load()'?".format(
                     self.__class__.__name__, attribute
                 )
             )
@@ -45,14 +53,31 @@ class RedditBase(AsyncPRAWBase):
         """Return the hash of the current instance."""
         return hash(self.__class__.__name__) ^ hash(str(self).lower())
 
-    def __init__(self, reddit: "Reddit", _data: Optional[Dict[str, Any]]):
+    def __init__(
+        self,
+        reddit: "Reddit",
+        _data: Optional[Dict[str, Any]],
+        _extra_attribute_to_check: Optional[str] = None,
+        _fetched: bool = False,
+        _str_field: bool = True,
+    ):
         """Initialize a RedditBase instance (or a subclass).
 
         :param reddit: An instance of :class:`~.Reddit`.
 
         """
         super().__init__(reddit, _data=_data)
-        self._fetched = False
+        self._fetched = _fetched
+        if _str_field and self.STR_FIELD not in self.__dict__:
+            if (
+                _extra_attribute_to_check is not None
+                and _extra_attribute_to_check in self.__dict__
+            ):
+                return
+            raise ValueError(
+                f"An invalid value was specified for {self.STR_FIELD}. Check that the "
+                f"argument for the {self.STR_FIELD} parameter is not empty."
+            )
 
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
@@ -78,8 +103,8 @@ class RedditBase(AsyncPRAWBase):
     async def load(self):
         """Re-fetches the object.
 
-        This is used to explicitly fetch the object from reddit. This method can be used
-        on any :class:`.RedditBase` object.
+        This is used to explicitly fetch or re-fetch the object from reddit. This method
+        can be used on any :class:`.RedditBase` object.
 
         .. code-block:: python
 
