@@ -6,6 +6,7 @@ from ...exceptions import ClientException
 from ...util.cache import cachedproperty
 from ..base import AsyncPRAWBase
 from .base import RedditBase
+from .redditor import Redditor
 from .submission import Submission
 from .subreddit import Subreddit
 
@@ -112,19 +113,19 @@ class Collection(RedditBase):
         :param collection_id: The ID of the Collection (optional).
         :param permalink: The permalink of the Collection (optional).
         """
-        super().__init__(reddit, _data)
-
         if (_data, collection_id, permalink).count(None) != 2:
             raise TypeError(
                 "Exactly one of _data, collection_id, or permalink must be provided."
             )
 
-        if permalink is not None:
+        if permalink:
             collection_id = self._url_parts(permalink)[4]
 
-        if collection_id is not None:
+        if collection_id:
             self.collection_id = collection_id  # set from _data otherwise
 
+        super().__init__(reddit, _data)
+
         self._info_params = {
             "collection_id": self.collection_id,
             "include_links": True,
@@ -163,13 +164,13 @@ class Collection(RedditBase):
     def __setattr__(self, attribute: str, value: Any):
         """Objectify author, subreddit, and sorted_links attributes."""
         if attribute == "author_name":
-            self.author = value
+            self.author = Redditor(self._reddit, name=attribute)
         elif attribute == "sorted_links":
             value = self._reddit._objector.objectify(value)
         super().__setattr__(attribute, value)
 
     def _fetch_info(self):
-        return ("collection", {}, self._info_params)
+        return "collection", {}, self._info_params
 
     async def _fetch_data(self):
         name, fields, params = self._fetch_info()
@@ -185,12 +186,11 @@ class Collection(RedditBase):
             # causes Reddit to return something that looks like an error
             # but with no content.
             raise ClientException(
-                f"Error during fetch. Check collection ID {self.collection_id!r} is "
-                f"correct."
+                f"Error during fetch. Check collection ID {self.collection_id!r} is"
+                " correct."
             )
 
         other = type(self)(self._reddit, _data=data)
-        other.author_name = await self._reddit.redditor(other.author_name)
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
@@ -308,7 +308,8 @@ class CollectionModeration(AsyncPRAWBase):
 
         """
         await self._reddit.post(
-            API_PATH["collection_delete"], data={"collection_id": self.collection_id},
+            API_PATH["collection_delete"],
+            data={"collection_id": self.collection_id},
         )
 
     async def remove_post(self, submission: Submission):
