@@ -13,11 +13,11 @@ from .mixins import (
     UserContentMixin,
 )
 from .redditor import Redditor
+from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
     from ... import Reddit
     from .submission import Submission
-    from .subreddit import Subreddit  # noqa: F401
 
 
 class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
@@ -51,6 +51,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     ``permalink``           A permalink for the comment. Comment objects from
                             the inbox have a ``context`` attribute instead.
     ``replies``             Provides an instance of :class:`.CommentForest`.
+    ``saved``               Whether or not the comment is saved.
     ``score``               The number of upvotes for the comment.
     ``stickied``            Whether or not the comment is stickied.
     ``submission``          Provides an instance of :class:`.Submission`. The
@@ -90,8 +91,8 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     def is_root(self) -> bool:
         """Return True when the comment is a top level comment.
 
-        .. note:: This property requires the comment to be fetched. Otherwise, an
-                   ``AttributeError`` will be raised.
+        :raises: :py:class:`AttributeError` if the comment is not fetched.
+
         """
         parent_type = self.parent_id.split("_", 1)[0]
         return parent_type == self._reddit.config.kinds["submission"]
@@ -170,15 +171,16 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         """Construct an instance of the Comment object."""
         if (id, url, _data).count(None) != 2:
             raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
+        fetched = False
         self._replies = []
         self._submission = None
-        super().__init__(reddit, _data=_data)
         if id:
             self.id = id
         elif url:
             self.id = self.id_from_url(url)
         else:
-            self._fetched = True
+            fetched = True
+        super().__init__(reddit, _data=_data, _fetched=fetched)
 
     def __setattr__(
         self,
@@ -196,13 +198,11 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
             attribute = "_replies"
         elif attribute == "subreddit":
             if isinstance(value, str):
-                from .. import Subreddit
-
                 value = Subreddit(self._reddit, display_name=value)
         super().__setattr__(attribute, value)
 
     def _fetch_info(self):
-        return ("info", {}, {"id": self.fullname})
+        return "info", {}, {"id": self.fullname}
 
     async def _fetch_data(self):
         name, fields, params = self._fetch_info()
@@ -278,8 +278,12 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         """
         # pylint: disable=no-member
 
-        await self._fetch()
-        await self.submission._fetch()
+        if not self._fetched:
+            await self._fetch()
+
+        if not self.submission._fetched:
+            await self.submission._fetch()
+
         if self.parent_id == self.submission.fullname:
             return self.submission
 
