@@ -80,8 +80,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
 
     def __init__(self, reddit: "Reddit", _data: Dict[str, Any]):
         """Construct an instance of the Message object."""
-        super().__init__(reddit, _data=_data)
-        self._fetched = True
+        super().__init__(reddit, _data=_data, _fetched=True)
 
     async def delete(self):
         """Delete the message.
@@ -116,7 +115,8 @@ class SubredditMessage(Message):
     Attribute               Description
     ======================= ===================================================
     ``author``              Provides an instance of :class:`.Redditor`.
-    ``body``                The body of the message.
+    ``body``                The body of the message, as Markdown.
+    ``body_html``           The body of the message, as HTML.
     ``created_utc``         Time the message was created, represented in
                             `Unix Time`_.
     ``dest``                Provides an instance of :class:`.Redditor`. The
