@@ -16,16 +16,18 @@ class MessageableMixin:
         message: str,
         from_subreddit: Optional[Union["Subreddit", str]] = None,
     ):
-        """
-        Send a message to a redditor or a subreddit's moderators (mod mail).
+        """Send a message to a redditor or a subreddit's moderators (mod mail).
 
         :param subject: The subject of the message.
         :param message: The message content.
-        :param from_subreddit: A :class:`~.Subreddit` instance or string to
-            send the message from. When provided, messages are sent from
-            the subreddit rather than from the authenticated user.
-            Note that the authenticated user must be a moderator of the
-            subreddit and have the ``mail`` moderator permission.
+        :param from_subreddit: A :class:`~.Subreddit` instance or string to send the
+            message from. When provided, messages are sent from the subreddit rather
+            than from the authenticated user.
+
+            .. note::
+
+                The authenticated user must be a moderator of the subreddit and have the
+                ``mail`` moderator permission.
 
         For example, to send a private message to ``u/spez``, try:
 
