@@ -90,7 +90,10 @@ class ModmailConversation(RedditBase):
 
     @classmethod
     def parse(  # pylint: disable=arguments-differ
-        cls, data: Dict[str, Any], reddit: "Reddit", convert_objects: bool = True,
+        cls,
+        data: Dict[str, Any],
+        reddit: "Reddit",
+        convert_objects: bool = True,
     ):
         """Return an instance of ModmailConversation from ``data``.
 
@@ -131,14 +134,15 @@ class ModmailConversation(RedditBase):
             (default: False).
 
         """
-        super().__init__(reddit, _data=_data)
         if bool(id) == bool(_data):
             raise TypeError("Either `id` or `_data` must be provided.")
 
         if id:
             self.id = id
 
-        self._info_params = {"markRead": "true"} if mark_read else None
+        super().__init__(reddit, _data=_data)
+
+        self._info_params = {"markRead": True} if mark_read else None
 
     def _build_conversation_list(self, other_conversations):
         """Return a comma-separated list of conversation IDs."""
@@ -187,9 +191,12 @@ class ModmailConversation(RedditBase):
         """
         await self._reddit.post(API_PATH["modmail_highlight"].format(id=self.id))
 
-    async def mute(self):
+    async def mute(self, num_days=3):
         """Mute the non-mod user associated with the conversation.
 
+        :param num_days: Duration of mute in days. Valid options are 3, 7, or 28.
+            (default: 3)
+
         For example:
 
         .. code-block:: python
@@ -198,8 +205,23 @@ class ModmailConversation(RedditBase):
             conversation = await subreddit.modmail("2gmz")
             await conversation.mute()
 
+        To mute for 7 days:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("redditdev")
+            conversation = await subreddit.modmail("2gmz")
+            await conversation.mute(7)
+
+
         """
-        await self._reddit.request("POST", API_PATH["modmail_mute"].format(id=self.id))
+        if num_days != 3:  # no need to pass params if it's the default
+            params = {"num_hours": num_days * 24}
+        else:
+            params = {}
+        await self._reddit.request(
+            "POST", API_PATH["modmail_mute"].format(id=self.id), params=params
+        )
 
     async def read(
         self, other_conversations: Optional[List["ModmailConversation"]] = None
