@@ -111,12 +111,13 @@ class SubmissionModeration(ThingModerationMixin):
             (default: True).
 
         Contest mode have the following effects:
-          * The comment thread will default to being sorted randomly.
-          * Replies to top-level comments will be hidden behind
-            "[show replies]" buttons.
-          * Scores will be hidden from non-moderators.
-          * Scores accessed through the API (mobile apps, bots) will be
-            obscured to "1" for non-moderators.
+
+        * The comment thread will default to being sorted randomly.
+        * Replies to top-level comments will be hidden behind "[show replies]"
+          buttons.
+        * Scores will be hidden from non-moderators.
+        * Scores accessed through the API (mobile apps, bots) will be obscured to
+          "1" for non-moderators.
 
         Example usage:
 
@@ -127,7 +128,8 @@ class SubmissionModeration(ThingModerationMixin):
 
         """
         await self.thing._reddit.post(
-            API_PATH["contest_mode"], data={"id": self.thing.fullname, "state": state},
+            API_PATH["contest_mode"],
+            data={"id": self.thing.fullname, "state": state},
         )
 
     async def flair(
@@ -180,7 +182,9 @@ class SubmissionModeration(ThingModerationMixin):
             submission = await subreddit.submit("nsfw test", selftext="nsfw")
             await submission.mod.nsfw()
 
-        .. seealso:: :meth:`~.sfw`
+        .. seealso::
+
+             :meth:`~.sfw`
 
         """
         await self.thing._reddit.post(
@@ -203,7 +207,9 @@ class SubmissionModeration(ThingModerationMixin):
             submission = await subreddit.submit("oc test", selftext="original")
             await submission.mod.set_original_content()
 
-        .. seealso:: :meth:`.unset_original_content`
+        .. seealso::
+
+             :meth:`.unset_original_content`
 
         """
         data = {
@@ -228,7 +234,9 @@ class SubmissionModeration(ThingModerationMixin):
             submission = await reddit.submission(id="5or86n", lazy=True)
             await submission.mod.sfw()
 
-        .. seealso:: :meth:`~.nsfw`
+        .. seealso::
+
+            :meth:`~.nsfw`
 
         """
         await self.thing._reddit.post(
@@ -248,7 +256,9 @@ class SubmissionModeration(ThingModerationMixin):
             submission = await reddit.submission(id="5or86n", lazy=True)
             await submission.mod.spoiler()
 
-        .. seealso:: :meth:`~.unspoiler`
+        .. seealso::
+
+            :meth:`~.unspoiler`
 
         """
         await self.thing._reddit.post(
@@ -297,7 +307,8 @@ class SubmissionModeration(ThingModerationMixin):
 
         """
         await self.thing._reddit.post(
-            API_PATH["suggested_sort"], data={"id": self.thing.fullname, "sort": sort},
+            API_PATH["suggested_sort"],
+            data={"id": self.thing.fullname, "sort": sort},
         )
 
     async def unset_original_content(self):
@@ -316,7 +327,9 @@ class SubmissionModeration(ThingModerationMixin):
             submission = await subreddit.submit("oc test", selftext="original")
             await submission.mod.unset_original_content()
 
-        .. seealso:: :meth:`.set_original_content`
+        .. seealso::
+
+            :meth:`.set_original_content`
 
         """
         data = {
@@ -338,11 +351,13 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            sub await reddit.subreddit("test")
+            sub = await reddit.subreddit("test")
             submission = await sub.submit("not spoiler", selftext="spoiler")
             await submission.mod.unspoiler()
 
-        .. seealso:: :meth:`~.spoiler`
+        .. seealso::
+
+            :meth:`~.spoiler`
 
         """
         await self.thing._reddit.post(
@@ -390,6 +405,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     ``poll_data``               A :class:`.PollData` object representing the
                                 data of this submission, if it is a poll
                                 submission.
+    ``saved``                   Whether or not the submission is saved.
     ``score``                   The number of upvotes for the submission.
     ``selftext``                The submissions' selftext - an empty string if
                                 a link post.
@@ -421,17 +437,25 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
             * https://redd.it/2gmzqe
             * https://reddit.com/comments/2gmzqe/
             * https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https/
+            * https://www.reddit.com/gallery/2gmzqe
 
         :raises: :class:`.InvalidURL` if URL is not a valid submission URL.
 
         """
         parts = RedditBase._url_parts(url)
-        if "comments" not in parts:
+        if "comments" not in parts and "gallery" not in parts:
             submission_id = parts[-1]
             if "r" in parts:
                 raise InvalidURL(
                     url, message="Invalid URL (subreddit, not submission): {}"
                 )
+
+        elif "gallery" in parts:
+            submission_id = parts[parts.index("gallery") + 1]
+
+        elif parts[-1] == "comments":
+            raise InvalidURL(url, message="Invalid URL (submission id not present): {}")
+
         else:
             submission_id = parts[parts.index("comments") + 1]
 
@@ -447,15 +471,17 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     async def comments(self) -> CommentForest:
         """Provide an instance of :class:`.CommentForest`.
 
-        This attribute can use used, for example, to obtain a flat list of
+        This attribute can be used, for example, to obtain a flat list of
         comments, with any :class:`.MoreComments` removed:
 
         .. code-block:: python
 
-            comments = await submission.comments
+            comments = await submission.comments()
             await comments.replace_more(limit=0)
-            async for comment in comments.list():
+            comment_list = await comments.list()
+            for comment in comment_list:
                 # do stuff with comment
+                ...
 
         Sort order and comment limit can be set with the ``comment_sort`` and
         ``comment_limit`` attributes before comments are fetched, including
@@ -464,10 +490,11 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         .. code-block:: python
 
             submission.comment_sort = "new"
-            comments = await submission.comments
+            comments = await submission.comments()
             comment_list = await comments.list()
-            for comment in list:
+            for comment in comment_list:
                 # do stuff with comment
+                ...
 
         .. note:: The appropriate values for ``comment_sort`` include
            ``confidence``, ``controversial``, ``new``, ``old``, ``q&a``,
@@ -520,7 +547,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def shortlink(self) -> str:
         """Return a shortlink to the submission.
 
-        For example http://redd.it/eorhm is a shortlink for
+        For example, https://redd.it/eorhm is a shortlink for
         https://www.reddit.com/r/announcements/comments/eorhm/reddit_30_less_typing/.
 
         """
@@ -545,17 +572,18 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         """
         if (id, url, _data).count(None) != 2:
             raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
-        super().__init__(reddit, _data=_data)
         self.comment_limit = 2048
 
         # Specify the sort order for ``comments``
         self.comment_sort = "confidence"
 
-        if id is not None:
+        if id:
             self.id = id
-        elif url is not None:
+        elif url:
             self.id = self.id_from_url(url)
 
+        super().__init__(reddit, _data=_data)
+
         self._comments_by_id = {}
 
     def __setattr__(self, attribute: str, value: Any):
@@ -634,7 +662,9 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
             submission = await reddit.submission(id="5or86n", lazy=True)
             await submission.hide()
 
-        .. seealso:: :meth:`~.unhide`
+        .. seealso::
+
+            :meth:`~.unhide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -654,7 +684,9 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
             submission = await reddit.submission(id="5or86n")
             await submission.unhide()
 
-        .. seealso:: :meth:`~.hide`
+        .. seealso::
+
+            :meth:`~.hide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -700,7 +732,9 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
             cross_post = await submission.crosspost(subreddit="learnprogramming",
                                               send_replies=False)
 
-        .. seealso:: :meth:`~.hide`
+        .. seealso::
+
+            :meth:`~.hide`
 
         """
         if title is None:
