@@ -1,5 +1,5 @@
 """Provide the WikiPage class."""
-from typing import TYPE_CHECKING, Any, Dict, AsyncGenerator, Optional, Union
+from typing import TYPE_CHECKING, Any, AsyncGenerator, Dict, Optional, Union
 
 from ...const import API_PATH
 from ...util.cache import cachedproperty
@@ -96,7 +96,7 @@ class WikiPageModeration:
         :param other_settings: Additional keyword arguments to pass.
         :returns: The updated WikiPage settings.
 
-        To set the wikipage ``praw_test`` in ``/r/test`` to mod only and
+        To set the wikipage ``praw_test`` in ``r/test`` to mod only and
         disable it from showing in the page list, try:
 
         .. code-block:: python
@@ -191,12 +191,13 @@ class WikiPage(RedditBase):
         self.name = name
         self._revision = revision
         self.subreddit = subreddit
-        super().__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data, _str_field=False)
 
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
-        return "{}(subreddit={!r}, name={!r})".format(
-            self.__class__.__name__, self.subreddit, self.name
+        return (
+            f"{self.__class__.__name__}(subreddit={self.subreddit!r},"
+            f" name={self.name!r})"
         )
 
     def __str__(self) -> str:
@@ -246,13 +247,14 @@ class WikiPage(RedditBase):
         """
         other_settings.update({"content": content, "page": self.name, "reason": reason})
         await self._reddit.post(
-            API_PATH["wiki_edit"].format(subreddit=self.subreddit), data=other_settings,
+            API_PATH["wiki_edit"].format(subreddit=self.subreddit),
+            data=other_settings,
         )
 
     async def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
-        To view revision ``[ID]`` of ``"praw_test"`` in ``/r/test``:
+        To view revision ``[ID]`` of ``"praw_test"`` in ``r/test``:
 
         .. code-block:: python
 
@@ -273,7 +275,7 @@ class WikiPage(RedditBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        To view the wiki revisions for ``"praw_test"`` in ``/r/test`` try:
+        To view the wiki revisions for ``"praw_test"`` in ``r/test`` try:
 
         .. code-block:: python
 
