@@ -1,7 +1,8 @@
 """Provide helper classes used by other models."""
-import random
 import asyncio
-from typing import Any, Callable, AsyncGenerator, List, Optional, Set
+import random
+from collections import OrderedDict
+from typing import Any, AsyncGenerator, Callable, List, Optional, Set
 
 
 class BoundedSet:
@@ -13,19 +14,23 @@ class BoundedSet:
     def __init__(self, max_items: int):
         """Construct an instance of the BoundedSet."""
         self.max_items = max_items
-        self._fifo = []
-        self._set = set()
+        self._set = OrderedDict()
 
     def __contains__(self, item: Any) -> bool:
         """Test if the BoundedSet contains item."""
+        self._access(item)
         return item in self._set
 
+    def _access(self, item: Any):
+        if item in self._set:
+            self._set.move_to_end(item)
+
     def add(self, item: Any):
         """Add an item to the set discarding the oldest item if necessary."""
-        if len(self._set) == self.max_items:
-            self._set.remove(self._fifo.pop(0))
-        self._fifo.append(item)
-        self._set.add(item)
+        self._access(item)
+        self._set[item] = None
+        if len(self._set) > self.max_items:
+            self._set.popitem(last=False)
 
 
 class ExponentialCounter:
@@ -34,8 +39,11 @@ class ExponentialCounter:
     def __init__(self, max_counter: int):
         """Initialize an instance of ExponentialCounter.
 
-        :param max_counter: The maximum base value. Note that the computed
-            value may be 3.125% higher due to jitter.
+        :param max_counter: The maximum base value.
+
+            .. note::
+
+                The computed value may be 3.125% higher due to jitter.
         """
         self._base = 1
         self._max = max_counter
@@ -62,13 +70,12 @@ def permissions_string(
        all. When prefixed, the resulting string will simply be the joining of
        these inputs. When not prefixed, all permissions are considered to be
        additions, and all permissions in the ``known_permissions`` set that
-       aren't provided are considered to be removals. When None, the result is
-       ``+all``.
+       aren't provided are considered to be removals. When ``None``, the result is
+       ``"+all"``.
     :param known_permissions: A set of strings representing the available
        permissions.
 
     """
-    to_set = []
     if permissions is None:
         to_set = ["+all"]
     else:
@@ -122,8 +129,7 @@ async def stream_generator(
     .. code-block:: python
 
         reply_function = reddit.inbox.comment_replies
-        reply_stream = asyncpraw.models.util.stream_generator(reply_function)
-        async for reply in reply_stream:
+        async for reply in asyncpraw.models.util.stream_generator(reply_function):
             print(reply)
 
     To pause a comment stream after six responses with no new
@@ -182,7 +188,7 @@ async def stream_generator(
         if before_attribute is None:
             limit -= without_before_counter
             without_before_counter = (without_before_counter + 1) % 30
-        if not exclude_before and before_attribute:
+        if not exclude_before:
             function_kwargs["params"] = {"before": before_attribute}
         for item in reversed(
             [result async for result in function(limit=limit, **function_kwargs)]
