@@ -1,11 +1,11 @@
 """Provide the Reddit class."""
+import asyncio
 import configparser
 import os
 import re
-import asyncio
 from itertools import islice
 from logging import getLogger
-from typing import IO, Any, Dict, AsyncGenerator, Iterable, Optional, Type, Union
+from typing import IO, Any, AsyncGenerator, Dict, Iterable, Optional, Type, Union
 from warnings import warn
 
 from asyncprawcore import (
@@ -23,7 +23,7 @@ from asyncprawcore.exceptions import BadRequest
 
 from . import models
 from .config import Config
-from .const import API_PATH, USER_AGENT_FORMAT
+from .const import API_PATH, USER_AGENT_FORMAT, __version__
 from .exceptions import (
     ClientException,
     MissingRequiredAttributeException,
@@ -31,6 +31,13 @@ from .exceptions import (
 )
 from .objector import Objector
 
+try:
+    from update_checker import update_check
+
+    UPDATE_CHECKER_MISSING = False
+except ImportError:  # pragma: no cover
+    UPDATE_CHECKER_MISSING = True
+
 
 Comment = models.Comment
 Redditor = models.Redditor
@@ -56,6 +63,7 @@ class Reddit:
 
     """
 
+    update_checked = False
     _ratelimit_regex = re.compile(r"([0-9]{1,2}) (seconds?|minutes?)")
 
     @property
@@ -74,15 +82,14 @@ class Reddit:
         """Set or unset the use of the ReadOnlyAuthorizer.
 
         :raises: :class:`ClientException` when attempting to unset ``read_only``
-        and only the ReadOnlyAuthorizer is available.
+            and only the ReadOnlyAuthorizer is available.
 
         """
         if value:
             self._core = self._read_only_core
         elif self._authorized_core is None:
             raise ClientException(
-                "read_only cannot be unset as only the "
-                "ReadOnlyAuthorizer is available."
+                "read_only cannot be unset as only the ReadOnlyAuthorizer is available."
             )
         else:
             self._core = self._authorized_core
@@ -92,6 +99,7 @@ class Reddit:
         """Get validate_on_submit.
 
         .. deprecated:: 7.0
+
             If property :attr:`.validate_on_submit` is set to False, the
             behavior is deprecated by Reddit. This attribute will be removed
             around May-June 2020.
@@ -100,9 +108,9 @@ class Reddit:
         value = self._validate_on_submit
         if value is False:
             warn(
-                "Reddit will check for validation on all posts around "
-                "May-June 2020. It is recommended to check for validation"
-                " by setting reddit.validate_on_submit to True.",
+                "Reddit will check for validation on all posts around May-June 2020. It"
+                " is recommended to check for validation by setting"
+                " reddit.validate_on_submit to True.",
                 category=DeprecationWarning,
                 stacklevel=3,
             )
@@ -112,20 +120,47 @@ class Reddit:
     def validate_on_submit(self, val: bool):
         self._validate_on_submit = val
 
-    def __enter__(self):
+    async def __aenter__(self):
         """Handle the context manager open."""
         return self
 
+    async def __aexit__(self, *_args):
+        """Handle the context manager close."""
+        await self.close()
+
+    def __enter__(self):
+        """Handle the context manager open.
+
+        .. deprecated:: 7.1.1
+
+            Using this class as a synchronous context manager is deprecated and will
+            be removed in the next release. Use this class as an asynchronous context
+            manager instead.
+
+        """
+        warn(
+            "Using this class as a synchronous context manager is deprecated and will"
+            " be removed in the next release. Use this class as an asynchronous context"
+            " manager instead.",
+            category=DeprecationWarning,
+            stacklevel=3,
+        )
+        return self  # pragma: no cover
+
     def __exit__(self, *_args):
         """Handle the context manager close."""
 
+    async def close(self):
+        """Close the requestor."""
+        await self.requestor.close()
+
     def __init__(
         self,
         site_name: str = None,
         config_interpolation: Optional[str] = None,
         requestor_class: Optional[Type[Requestor]] = None,
         requestor_kwargs: Dict[str, Any] = None,
-        **config_settings: str,
+        **config_settings: Union[str, bool],
     ):  # noqa: D207, D301
         """Initialize a Reddit instance.
 
@@ -163,7 +198,13 @@ class Reddit:
 
         .. code-block:: python
 
-            import json, aiohttp
+            import json
+
+            import aiohttp
+            from asyncprawcore import Requestor
+
+            from asyncpraw import Reddit
+
 
             class JSONDebugRequestor(Requestor):
                 async def request(self, *args, **kwargs):
@@ -175,6 +216,24 @@ class Reddit:
             reddit = Reddit(..., requestor_class=JSONDebugRequestor,
                             requestor_kwargs={"session": my_session})
 
+        You can automatically close the requestor session by using this class as an
+        context manager:
+
+        .. code-block:: python
+
+            async with Reddit(...) as reddit:
+                print(await reddit.user.me())
+
+        You can also call :meth:`.Reddit.close`:
+
+        .. code-block:: python
+
+            reddit = Reddit(...)
+            # do stuff with reddit
+            ...
+            # then close the requestor when done
+            await reddit.close()
+
         """
         self._core = self._authorized_core = self._read_only_core = None
         self._objector = None
@@ -188,24 +247,20 @@ class Reddit:
             )
         except configparser.NoSectionError as exc:
             help_message = (
-                "You provided the name of a praw.ini "
-                "configuration which does not exist.\n\nFor help "
-                "with creating a Reddit instance, visit\n"
-                "https://asyncpraw.readthedocs.io/en/latest/code_overvi"
-                "ew/reddit_instance.html\n\n"
-                "For help on configuring Async PRAW, visit\n"
-                "https://asyncpraw.readthedocs.io/en/latest/getting_sta"
-                "rted/configuration.html"
+                "You provided the name of a praw.ini configuration which does not"
+                " exist.\n\nFor help with creating a Reddit instance,"
+                " visit\nhttps://asyncpraw.readthedocs.io/en/latest/code_overview/reddit_instance.html\n\nFor"
+                " help on configuring Async PRAW,"
+                " visit\nhttps://asyncpraw.readthedocs.io/en/latest/getting_started/configuration.html"
             )
             if site_name is not None:
-                exc.message += "\n" + help_message
+                exc.message += f"\n{help_message}"
             raise
 
         required_message = (
-            "Required configuration setting {!r} missing. \n"
-            "This setting can be provided in a praw.ini file, "
-            "as a keyword argument to the `Reddit` class "
-            "constructor, or as an environment variable."
+            "Required configuration setting {!r} missing. \nThis setting can be"
+            " provided in a praw.ini file, as a keyword argument to the `Reddit` class"
+            " constructor, or as an environment variable."
         )
         for attribute in ("client_id", "user_agent"):
             if getattr(self.config, attribute) in (self.config.CONFIG_NOT_SET, None):
@@ -214,20 +269,23 @@ class Reddit:
                 )
         if self.config.client_secret is self.config.CONFIG_NOT_SET:
             raise MissingRequiredAttributeException(
-                required_message.format("client_secret")
-                + "\nFor installed applications this value "
-                "must be set to None via a keyword argument "
-                "to the `Reddit` class constructor."
+                f"{required_message.format('client_secret')}\nFor installed"
+                " applications this value must be set to None via a keyword argument"
+                " to the `Reddit` class constructor."
             )
-
+        self._check_for_update()
         self._prepare_objector()
-        self._prepare_asyncprawcore(requestor_class, requestor_kwargs)
+        self.requestor = self._prepare_asyncprawcore(requestor_class, requestor_kwargs)
 
         self.auth = models.Auth(self, None)
         """An instance of :class:`.Auth`.
 
         Provides the interface for interacting with installed and web
-        applications. See :ref:`auth_url`
+        applications.
+
+        .. seealso::
+
+            :ref:`auth_url`
 
         """
 
@@ -249,7 +307,7 @@ class Reddit:
 
         Provides the interface to a user's inbox which produces
         :class:`.Message`, :class:`.Comment`, and :class:`.Submission`
-        instances. For example to iterate through comments which mention the
+        instances. For example, to iterate through comments which mention the
         authorized user run:
 
         .. code-block:: python
@@ -275,25 +333,25 @@ class Reddit:
         """An instance of :class:`.MultiredditHelper`.
 
         Provides the interface to working with :class:`.Multireddit`
-        instances. For example you can obtain a :class:`.Multireddit` instance
+        instances. For example, you can obtain a :class:`.Multireddit` instance
         via:
 
         .. code-block:: python
 
             multireddit = await reddit.multireddit("samuraisam", "programming")
 
-        If you want to obtain a :class:`.Multireddit` instance you can do:
+        If you want to obtain a fetched :class:`.Multireddit` instance you can do:
 
         .. code-block:: python
 
-            multireddit = await reddit.multireddit("samuraisam", "programming")
+            multireddit = await reddit.multireddit("samuraisam", "programming", fetch=True)
 
         """
 
         self.redditors = models.Redditors(self, None)
         """An instance of :class:`.Redditors`.
 
-        Provides the interface for Redditor discovery. For example
+        Provides the interface for Redditor discovery. For example,
         to iterate over the newest Redditors, run:
 
         .. code-block:: python
@@ -307,7 +365,7 @@ class Reddit:
         """An instance of :class:`.SubredditHelper`.
 
         Provides the interface to working with :class:`.Subreddit`
-        instances. For example to create a Subreddit run:
+        instances. For example, to create a Subreddit run:
 
         .. code-block:: python
 
@@ -325,7 +383,7 @@ class Reddit:
 
             await reddit.subreddit("redditdev", fetch=True)
 
-        Note that multiple subreddits can be combined and filtered views of
+        Multiple subreddits can be combined and filtered views of
         r/all can also be used just like a subreddit:
 
         .. code-block:: python
@@ -338,7 +396,7 @@ class Reddit:
         self.subreddits = models.Subreddits(self, None)
         """An instance of :class:`.Subreddits`.
 
-        Provides the interface for :class:`.Subreddit` discovery. For example
+        Provides the interface for :class:`.Subreddit` discovery. For example,
         to iterate over the set of default subreddits run:
 
         .. code-block:: python
@@ -352,7 +410,7 @@ class Reddit:
         """An instance of :class:`.User`.
 
         Provides the interface to the currently authorized
-        :class:`.Redditor`. For example to get the name of the current user
+        :class:`.Redditor`. For example, to get the name of the current user
         run:
 
         .. code-block:: python
@@ -361,6 +419,13 @@ class Reddit:
 
         """
 
+    def _check_for_update(self):
+        if UPDATE_CHECKER_MISSING:
+            return
+        if not Reddit.update_checked and self.config.check_for_updates:
+            update_check(__package__, __version__)
+            Reddit.update_checked = True
+
     def _prepare_objector(self):
         mappings = {
             self.config.kinds["comment"]: models.Comment,
@@ -391,6 +456,7 @@ class Reddit:
             "image": models.ImageWidget,
             "menu": models.Menu,
             "modaction": models.ModAction,
+            "moderator-list": models.ModeratorListing,
             "moderators": models.ModeratorsWidget,
             "more": models.MoreComments,
             "post-flair": models.PostFlairWidget,
@@ -418,6 +484,8 @@ class Reddit:
         else:
             self._prepare_untrusted_asyncprawcore(requestor)
 
+        return requestor
+
     def _prepare_trusted_asyncprawcore(self, requestor):
         authenticator = TrustedAuthenticator(
             requestor,
@@ -504,14 +572,19 @@ class Reddit:
         return await self._objectify_request(method="GET", params=params, path=path)
 
     def info(
-        self, fullnames: Optional[Iterable[str]] = None, url: Optional[str] = None,
+        self,
+        fullnames: Optional[Iterable[str]] = None,
+        url: Optional[str] = None,
+        subreddits: Optional[Iterable[Union[Subreddit, str]]] = None,
     ) -> AsyncGenerator[Union[Subreddit, Comment, Submission], None]:
-        """Fetch information about each item in ``fullnames`` or from ``url``.
+        """Fetch information about each item in ``fullnames``, ``url``, or ``subreddits``.
 
         :param fullnames: A list of fullnames for comments, submissions, and/or
             subreddits.
         :param url: A url (as a string) to retrieve lists of link submissions
             from.
+        :param subreddits: A list of subreddit names or Subreddit objects to retrieve
+            subreddits from.
         :returns: A generator that yields found items in their relative order.
 
         Items that cannot be matched will not be generated. Requests will be
@@ -527,24 +600,33 @@ class Reddit:
                   different set of submissions.
 
         """
-        none_count = (fullnames, url).count(None)
-        if none_count > 1:
-            raise TypeError("Either `fullnames` or `url` must be provided.")
-        if none_count < 1:
-            raise TypeError("Mutually exclusive parameters: `fullnames`, `url`")
+        none_count = (fullnames, url, subreddits).count(None)
+        if none_count != 2:
+            raise TypeError(
+                "Either `fullnames`, `url`, or `subreddits` must be provided."
+            )
 
-        if fullnames is not None:
-            if isinstance(fullnames, str):
-                raise TypeError("`fullnames` must be a non-str iterable.")
+        is_using_fullnames = fullnames is not None
+        ids_or_names = fullnames if is_using_fullnames else subreddits
+
+        if ids_or_names is not None:
+            if isinstance(ids_or_names, str):
+                raise TypeError(
+                    "`fullnames` and `subreddits` must be a non-str iterable."
+                )
+
+            api_parameter_name = "id" if is_using_fullnames else "sr_name"
 
             async def generator(fullnames):
-                iterable = iter(fullnames)
+                if is_using_fullnames:
+                    iterable = iter(ids_or_names)
+                else:
+                    iterable = iter([str(item) for item in ids_or_names])
                 while True:
                     chunk = list(islice(iterable, 100))
                     if not chunk:
                         break
-
-                    params = {"id": ",".join(chunk)}
+                    params = {api_parameter_name: ",".join(chunk)}
                     for result in await self.get(API_PATH["info"], params=params):
                         yield result
 
@@ -687,7 +769,11 @@ class Reddit:
                 logger.debug(f"Rate limit hit, sleeping for {seconds:.2f} seconds")
                 await asyncio.sleep(seconds)
                 return await self._objectify_request(
-                    data=data, files=files, method="POST", params=params, path=path,
+                    data=data,
+                    files=files,
+                    method="POST",
+                    params=params,
+                    path=path,
                 )
             raise
 
@@ -751,7 +837,7 @@ class Reddit:
         self,
         method: str,
         path: str,
-        params: Optional[Union[str, Dict[str, str]]] = None,
+        params: Optional[Union[str, Dict[str, Union[str, int]]]] = None,
         data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         files: Optional[Dict[str, IO]] = None,
         json=None,
@@ -771,16 +857,6 @@ class Reddit:
             (default: None). If ``json`` is provided, ``data`` should not be.
 
         """
-        # this a fix for aiohttp not liking bool values in its params; this should be
-        # fixed asyncprawcore
-        if params:
-            new_params = {}
-            for k, v in params.items():
-                if isinstance(v, bool):
-                    new_params[k] = str(v).lower()
-                elif v:
-                    new_params[k] = v
-            params = new_params
         if data and json:
             raise ClientException("At most one of `data` and `json` is supported.")
         try:
@@ -800,8 +876,8 @@ class Reddit:
                 # TODO: Remove this exception after 2020-12-31 if no one has
                 # filed a bug against it.
                 raise Exception(
-                    "Unexpected BadRequest without json body. Please file a "
-                    "bug at https://github.com/praw-dev/asyncpraw/issues"
+                    "Unexpected BadRequest without json body. Please file a bug at"
+                    " https://github.com/praw-dev/asyncpraw/issues"
                 ) from exception
             if set(data) == {"error", "message"}:
                 raise
