@@ -42,8 +42,8 @@ def send_message(client, message):
 async def main():
     """Provide the program's entry point when directly executed."""
     print(
-        "Go here while logged into the account you want to create a token for: "
-        "https://www.reddit.com/prefs/apps/"
+        "Go here while logged into the account you want to create a token for:"
+        " https://www.reddit.com/prefs/apps/"
     )
     print(
         "Click the create an app button. Put something in the name field and select the"
@@ -71,7 +71,7 @@ async def main():
     )
     state = str(random.randint(0, 65000))
     url = reddit.auth.url(scopes, state, "permanent")
-    print("Now open this url in your browser: " + url)
+    print(f"Now open this url in your browser: {url}")
     sys.stdout.flush()
 
     client = receive_connection()
@@ -83,7 +83,8 @@ async def main():
 
     if state != params["state"]:
         send_message(
-            client, f"State mismatch. Expected: {state} Received: {params['state']}",
+            client,
+            f"State mismatch. Expected: {state} Received: {params['state']}",
         )
         return 1
     elif "error" in params:
