@@ -1,7 +1,7 @@
 """Prepare py.test."""
+import asyncio
 import json
 import os
-import asyncio
 from base64 import b64encode
 from datetime import datetime
 from functools import wraps
@@ -52,8 +52,8 @@ def filter_access_token(response):
 placeholders = {
     x: env_default(x)
     for x in (
-        "auth_code client_id client_secret password redirect_uri "
-        "test_subreddit user_agent username refresh_token"
+        "auth_code client_id client_secret password redirect_uri test_subreddit"
+        " user_agent username refresh_token"
     ).split()
 }
 
@@ -103,7 +103,7 @@ class CustomSerializer(object):
     def serialize(cassette_dict):
         cassette_dict["recorded_at"] = datetime.now().isoformat()[:-7]
         return (
-            json.dumps(serialize_dict(cassette_dict), sort_keys=True, indent=2) + "\n"
+            f"{json.dumps(serialize_dict(cassette_dict), sort_keys=True, indent=2)}\n"
         )
 
     @staticmethod
