@@ -1,8 +1,8 @@
 import sys
 from os.path import abspath, dirname, join
-from asynctest import mock
 
 import pytest
+from asynctest import mock
 
 from asyncpraw.models import (
     Button,
@@ -107,7 +107,10 @@ class TestButtonWidget(IntegrationTest):
                 },
             ]
             widget = await widgets.mod.add_button_widget(
-                "Things to click", "Click some of these *cool* links!", buttons, styles,
+                "Things to click",
+                "Click some of these *cool* links!",
+                buttons,
+                styles,
             )
 
             assert isinstance(widget, ButtonWidget)
@@ -220,8 +223,8 @@ class TestCalendar(IntegrationTest):
             assert isinstance(widget, Calendar)
             assert widget.shortName == "Upcoming Events"
             assert (
-                widget.googleCalendarId == "ccahu0rstno2jrvioq4ccffn78@"
-                "group.calendar.google.com"
+                widget.googleCalendarId
+                == "ccahu0rstno2jrvioq4ccffn78@group.calendar.google.com"
             )
             assert widget.configuration == config
             assert widget.styles == styles
@@ -231,8 +234,8 @@ class TestCalendar(IntegrationTest):
             assert isinstance(widget, Calendar)
             assert widget.shortName == "Past Events :("
             assert (
-                widget.googleCalendarId == "ccahu0rstno2jrvioq4ccffn78@"
-                "group.calendar.google.com"
+                widget.googleCalendarId
+                == "ccahu0rstno2jrvioq4ccffn78@group.calendar.google.com"
             )
             assert widget.configuration == config
             assert widget.styles == styles
@@ -284,7 +287,8 @@ class TestCommunityList(IntegrationTest):
             assert "redditdev" in widget
 
             widget = await widget.mod.update(
-                shortName="My least fav subs :(", data=["redesign"],
+                shortName="My least fav subs :(",
+                data=["redesign"],
             )
 
             assert isinstance(widget, CommunityList)
@@ -720,7 +724,9 @@ class TestRulesWidget(IntegrationTest):
             assert rules.styles != new_styles
 
             rules = await rules.mod.update(
-                display="compact", shortName="Our regulations", styles=new_styles,
+                display="compact",
+                shortName="Our regulations",
+                styles=new_styles,
             )
 
             assert rules.display == "compact"
@@ -788,8 +794,8 @@ class TestSubredditWidgets(IntegrationTest):
         subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
         widgets = subreddit.widgets
         assert (
-            f"SubredditWidgets(subreddit=Subreddit(display_name='"
-            f"{pytest.placeholders.test_subreddit}'))" == repr(widgets)
+            f"SubredditWidgets(subreddit=Subreddit(display_name='{pytest.placeholders.test_subreddit}'))"
+            == repr(widgets)
         )
 
     async def test_sidebar(self):
