@@ -42,6 +42,11 @@ class TestSubmission(UnitTest):
             Submission(self.reddit, "dummy", "dummy", {"id": "dummy"})
         assert str(excinfo.value) == message
 
+        with pytest.raises(ValueError):
+            Submission(self.reddit, "")
+        with pytest.raises(ValueError):
+            Submission(self.reddit, url="")
+
     def test_construct_from_url(self):
         assert Submission(self.reddit, url="http://my.it/2gmzqe") == "2gmzqe"
 
@@ -66,8 +71,8 @@ class TestSubmission(UnitTest):
             "https://redd.it/2gmzqe",
             "https://redd.it/2gmzqe/",
             "http://reddit.com/comments/2gmzqe",
-            "https://www.reddit.com/r/redditdev/comments/2gmzqe/"
-            "praw_https_enabled_praw_testing_needed/",
+            "https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https_enabled_praw_testing_needed/",
+            "https://www.reddit.com/gallery/2gmzqe",
         ]
         for url in urls:
             assert Submission.id_from_url(url) == "2gmzqe", url
@@ -83,6 +88,8 @@ class TestSubmission(UnitTest):
             "http://reddit.com/comments/_/2gmzqe",
             "https://reddit.com/r/wallpapers/",
             "https://reddit.com/r/wallpapers",
+            "https://www.reddit.com/r/test/comments/",
+            "https://reddit.com/comments/",
         ]
         for url in urls:
             with pytest.raises(ClientException):
